summaryrefslogtreecommitdiffstats
path: root/kate/part/katebuffer.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:48:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:48:49 -0600
commit13281e2856a2ef43bbab78c5528470309c23aa77 (patch)
tree936bcf8145dc235004c73e9fb3d6b3dca9aa370b /kate/part/katebuffer.h
parente81c741bb2cf337a43524e75f22f7728ce17a343 (diff)
downloadtdelibs-13281e2856a2ef43bbab78c5528470309c23aa77.tar.gz
tdelibs-13281e2856a2ef43bbab78c5528470309c23aa77.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kate/part/katebuffer.h')
-rw-r--r--kate/part/katebuffer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kate/part/katebuffer.h b/kate/part/katebuffer.h
index 450f260ab..04ee264e8 100644
--- a/kate/part/katebuffer.h
+++ b/kate/part/katebuffer.h
@@ -116,7 +116,7 @@ class KateBufBlock
void removeLine(uint i);
/**
* mark this block as dirty, will tqinvalidate the swap data
* insert/removeLine will mark the block dirty itself
*/
void markDirty ();
@@ -611,7 +611,7 @@ class KateBuffer : public TQObject
* @returns true when the highlighting in the next block needs to be updated,
* false otherwise.
*/
- bool doHighlight (KateBufBlock *buf, uint from, uint to, bool tqinvalidate);
+ bool doHighlight (KateBufBlock *buf, uint from, uint to, bool invalidate);
signals:
/**
@@ -116,7 +116,7 @@ class KateBufBlock
void removeLine(uint i);
/**
- * mark this block as dirty, will tqinvalidate the swap data
+ * mark this block as dirty, will invalidate the swap data
* insert/removeLine will mark the block dirty itself
*/